==> huaweicloudsdkobs-3.1.75-py2.py3-none-any.whl: huaweicloudsdkobs/v1/model/buckets.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class Buckets:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    xml_name = "Buckets"

    sensitive_list = []

    openapi_types = {
        'bucket': 'list[Bucket]'
    }

    attribute_map = {
        'bucket': 'Bucket'
    }

    def __init__(self, bucket=None):
        """Buckets

        The model defined in huaweicloud sdk

        :param bucket: 用户所拥有的桶列表。 
        :type bucket: list[:class:`huaweicloudsdkobs.v1.Bucket`]
        """
        
        

        self._bucket = None
        self.discriminator = None

        if bucket is not None:
            self.bucket = bucket

    @property
    def bucket(self):
        """Gets the bucket of this Buckets.

        用户所拥有的桶列表。 

        :return: The bucket of this Buckets.
        :rtype: list[:class:`huaweicloudsdkobs.v1.Bucket`]
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this Buckets.

        用户所拥有的桶列表。 

        :param bucket: The bucket of this Buckets.
        :type bucket: list[:class:`huaweicloudsdkobs.v1.Bucket`]
        """
        self._bucket = bucket

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Buckets):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkobs-3.1.131-py2.py3-none-any.whl: huaweicloudsdkobs/v1/model/buckets.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class Buckets:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    xml_name = "Buckets"

    sensitive_list = []

    openapi_types = {
        'bucket': 'list[Bucket]'
    }

    attribute_map = {
        'bucket': 'Bucket'
    }

    def __init__(self, bucket=None):
        """Buckets

        The model defined in huaweicloud sdk

        :param bucket: List of buckets. 
        :type bucket: list[:class:`huaweicloudsdkobs.v1.Bucket`]
        """
        
        

        self._bucket = None
        self.discriminator = None

        if bucket is not None:
            self.bucket = bucket

    @property
    def bucket(self):
        """Gets the bucket of this Buckets.

        List of buckets. 

        :return: The bucket of this Buckets.
        :rtype: list[:class:`huaweicloudsdkobs.v1.Bucket`]
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this Buckets.

        List of buckets. 

        :param bucket: The bucket of this Buckets.
        :type bucket: list[:class:`huaweicloudsdkobs.v1.Bucket`]
        """
        self._bucket = bucket

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Buckets):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
